@@ -1,13 +1,14 @@
-from typing import List, Literal, Optional
+from typing import Literal, Optional
 
 from pydantic import BaseModel
 
 
 class EZItem(BaseModel):
     name: str
-    quantity: int
-    price: int
-    amount: int
+    quantity: float
+    price: float
+    amount: float
+    unit: str = "個"
 
 
 class IssueModel(BaseModel):
@@ -20,9 +21,14 @@ class IssueModel(BaseModel):
     BuyerUBN: Optional[str]
     BuyerAddress: Optional[str]
     BuyerEmail: Optional[str]
+    ItemName: str
+    ItemUnit: str
+    ItemPrice: str
+    ItemAmt: str
+    ItemCount: str
     CarrierType: Optional[Literal["0", "1", "2"]]
     CarrierNum: Optional[str]
-    LoveCode: Optional[int]
+    LoveCode: Optional[str]
     PrintFlag: Literal["Y", "N"] = "Y"
     TaxType: Literal["1", "2", "3", "9"] = "1"
     TaxRate: int = 5  # 5%
@@ -33,7 +39,6 @@ class IssueModel(BaseModel):
     AmtFree: Optional[int]
     TaxAmt: int
     TotalAmt: int
-    items: List[EZItem]
 
 
 class QueryModel(BaseModel):
@@ -48,3 +53,23 @@ class QueryModel(BaseModel):
 class VoidModel(BaseModel):
     InvoiceNumber: str
     InvalidReason: str
+
+
+class IssueResult(BaseModel):
+    CheckCode: str
+    MerchantID: str
+    MerchantOrderNo: str
+    InvoiceNumber: str
+    TotalAmt: str
+    InvoiceTransNo: str
+    RandomNum: str
+    CreateTime: str
+    BarCode: Optional[str]
+    QRcodeL: Optional[str]
+    QRcodeR: Optional[str]
+
+
+class IssueResp(BaseModel):
+    Status: str
+    Message: str
+    Result: Optional[IssueResult]
